==> haskell-crypto-random-0.0.9-335-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-KAWyqiuRWYqSRgBjXqeKZ
key:                  crypto-random-0.0.9-KAWyqiuRWYqSRgBjXqeKZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  b6b74ceee404c2d94a3000489bec7c51
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-random
hs-libraries:         HScrypto-random-0.0.9-KAWyqiuRWYqSRgBjXqeKZ
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    securemem-0.1.10-EDfBRjlOKD136c0ZXJQIUL unix-2.7.2.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-343-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-EFUlEYtkS1rFRk46Rgxei3
key:                  crypto-random-0.0.9-EFUlEYtkS1rFRk46Rgxei3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  0863facdab881c1ef18ac358058e6298
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-random
hs-libraries:         HScrypto-random-0.0.9-EFUlEYtkS1rFRk46Rgxei3
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    securemem-0.1.10-EDfBRjlOKD136c0ZXJQIUL unix-2.7.2.2
    vector-0.13.1.0-6zUlLOR49glIjajdp1B41

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
